==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dbforpostgresql/kotlin/inputs/GetRolePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbforpostgresql.kotlin.inputs

import com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the cluster.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property roleName The name of the cluster role.
 */
public data class GetRolePlainArgs(
    public val clusterName: String,
    public val resourceGroupName: String,
    public val roleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs =
        com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .roleName(roleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRolePlainArgs].
 */
@PulumiTagMarker
public class GetRolePlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    private var roleName: String? = null

    /**
     * @param value The name of the cluster.
     */
    @JvmName("blexvmlejngamuvc")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("lkssdtwiteggukej")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the cluster role.
     */
    @JvmName("yvwxbijuqxcergxh")
    public suspend fun roleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.roleName = mapped
    }

    internal fun build(): GetRolePlainArgs = GetRolePlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        roleName = roleName ?: throw PulumiNullFieldException("roleName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dbforpostgresql/kotlin/inputs/GetRolePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbforpostgresql.kotlin.inputs

import com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the cluster.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property roleName The name of the cluster role.
 */
public data class GetRolePlainArgs(
    public val clusterName: String,
    public val resourceGroupName: String,
    public val roleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs =
        com.pulumi.azurenative.dbforpostgresql.inputs.GetRolePlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .roleName(roleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRolePlainArgs].
 */
@PulumiTagMarker
public class GetRolePlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var resourceGroupName: String? = null

    private var roleName: String? = null

    /**
     * @param value The name of the cluster.
     */
    @JvmName("vvndovnvdjetxjed")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("pvkqyipotrhoygpn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the cluster role.
     */
    @JvmName("bvtcgeymrukeygep")
    public suspend fun roleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.roleName = mapped
    }

    internal fun build(): GetRolePlainArgs = GetRolePlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        roleName = roleName ?: throw PulumiNullFieldException("roleName"),
    )
}
